EXPORTS
	??0CBaseSmsActiveSocketWatcher@@IAE@AAVCWatcherLog@@HVTUid@@AAVRFs@@@Z @ 1 NONAME ; protected: __thiscall CBaseSmsActiveSocketWatcher::CBaseSmsActiveSocketWatcher(class CWatcherLog &,int,class TUid,class RFs &)
	??0CSmsBaseWatcher@@IAE@AAVRFs@@AAVCWatcherLog@@H@Z @ 2 NONAME ; protected: __thiscall CSmsBaseWatcher::CSmsBaseWatcher(class RFs &,class CWatcherLog &,int)
	??1CBaseSmsActiveSocketWatcher@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CBaseSmsActiveSocketWatcher::~CBaseSmsActiveSocketWatcher(void)
	??1CSmsBaseWatcher@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CSmsBaseWatcher::~CSmsBaseWatcher(void)
	?AddBifWithTypeL@CSmsBaseWatcher@@IAEXW4TBioMsgIdType@@VTUid@@@Z @ 5 NONAME ; protected: void __thiscall CSmsBaseWatcher::AddBifWithTypeL(enum TBioMsgIdType,class TUid)
	?Complete@CBaseSmsActiveSocketWatcher@@IAEXH@Z @ 6 NONAME ; protected: void __thiscall CBaseSmsActiveSocketWatcher::Complete(int)
	?CompleteMyself@CSmsBaseWatcher@@IAEXH@Z @ 7 NONAME ; protected: void __thiscall CSmsBaseWatcher::CompleteMyself(int)
	?ConstructL@CBaseSmsActiveSocketWatcher@@MAEXAAVCBIODatabase@@@Z @ 8 NONAME ; protected: virtual void __thiscall CBaseSmsActiveSocketWatcher::ConstructL(class CBIODatabase &)
	?ConstructL@CSmsBaseWatcher@@IAEXXZ @ 9 NONAME ; protected: void __thiscall CSmsBaseWatcher::ConstructL(void)
	?CreateSocketWatchersFromBioDbL@CSmsBaseWatcher@@IAEXW4TBioMsgIdType@@@Z @ 10 NONAME ; protected: void __thiscall CSmsBaseWatcher::CreateSocketWatchersFromBioDbL(enum TBioMsgIdType)
	?CreateSocketWatchersFromBioDbL@CSmsBaseWatcher@@IAEXW4TBioMsgIdType@@VTUid@@@Z @ 11 NONAME ; protected: void __thiscall CSmsBaseWatcher::CreateSocketWatchersFromBioDbL(enum TBioMsgIdType,class TUid)
	?DeleteBifL@CSmsBaseWatcher@@MAEXVTUid@@@Z @ 12 NONAME ; protected: virtual void __thiscall CSmsBaseWatcher::DeleteBifL(class TUid)
	?DeleteSocketWatchersWithUidL@CSmsBaseWatcher@@IAEXVTUid@@@Z @ 13 NONAME ; protected: void __thiscall CSmsBaseWatcher::DeleteSocketWatchersWithUidL(class TUid)
	?DoCancel@CSmsBaseWatcher@@MAEXXZ @ 14 NONAME ; protected: virtual void __thiscall CSmsBaseWatcher::DoCancel(void)
	?HandleBifChangeL@CSmsBaseWatcher@@MAEXW4TBifChangeEvent@MBifChangeObserver@@VTUid@@@Z @ 15 NONAME ; protected: virtual void __thiscall CSmsBaseWatcher::HandleBifChangeL(enum MBifChangeObserver::TBifChangeEvent,class TUid)
	?HandleWatcherComplete@CSmsBaseWatcher@@MAEXAAVCBaseSmsActiveSocketWatcher@@H@Z @ 16 NONAME ; protected: virtual void __thiscall CSmsBaseWatcher::HandleWatcherComplete(class CBaseSmsActiveSocketWatcher &,int)
	?ReloadBifL@CSmsBaseWatcher@@MAEXVTUid@@@Z @ 17 NONAME ; protected: virtual void __thiscall CSmsBaseWatcher::ReloadBifL(class TUid)
	?Reset@CSmsBaseWatcher@@MAEXXZ @ 18 NONAME ; protected: virtual void __thiscall CSmsBaseWatcher::Reset(void)
	?ResetDb@CSmsBaseWatcher@@IAEXXZ @ 19 NONAME ; protected: void __thiscall CSmsBaseWatcher::ResetDb(void)
	?RestoreSettingsL@CBaseSmsActiveSocketWatcher@@MAEXAAVCMsvSession@@@Z @ 20 NONAME ; protected: virtual void __thiscall CBaseSmsActiveSocketWatcher::RestoreSettingsL(class CMsvSession &)
	?RunError@CBaseSmsActiveSocketWatcher@@EAEHH@Z @ 21 NONAME ; protected: virtual int __thiscall CBaseSmsActiveSocketWatcher::RunError(int)
	?RunError@CSmsBaseWatcher@@MAEHH@Z @ 22 NONAME ; protected: virtual int __thiscall CSmsBaseWatcher::RunError(int)
	?RunL@CBaseSmsActiveSocketWatcher@@EAEXXZ @ 23 NONAME ; protected: virtual void __thiscall CBaseSmsActiveSocketWatcher::RunL(void)
	?RunL@CSmsBaseWatcher@@MAEXXZ @ 24 NONAME ; protected: virtual void __thiscall CSmsBaseWatcher::RunL(void)
	?SetBioMsgText@CBaseSmsActiveSocketWatcher@@MAEXAAVCBIODatabase@@@Z @ 25 NONAME ; protected: virtual void __thiscall CBaseSmsActiveSocketWatcher::SetBioMsgText(class CBIODatabase &)
	?SetupAndAppendL@CSmsBaseWatcher@@IAEHAAVCBaseSmsActiveSocketWatcher@@AAV?$CArrayPtrFlat@VCBaseSmsActiveSocketWatcher@@@@@Z @ 26 NONAME ; protected: int __thiscall CSmsBaseWatcher::SetupAndAppendL(class CBaseSmsActiveSocketWatcher &,class CArrayPtrFlat<class CBaseSmsActiveSocketWatcher> &)
	?SetupL@CBaseSmsActiveSocketWatcher@@QAEXXZ @ 27 NONAME ; public: void __thiscall CBaseSmsActiveSocketWatcher::SetupL(void)
	?StartL@CBaseSmsActiveSocketWatcher@@QAEXXZ @ 28 NONAME ; public: void __thiscall CBaseSmsActiveSocketWatcher::StartL(void)
	?StartL@CSmsBaseWatcher@@MAEXXZ @ 29 NONAME ; protected: virtual void __thiscall CSmsBaseWatcher::StartL(void)
	?StartSocketWatchersL@CSmsBaseWatcher@@IAEXXZ @ 30 NONAME ; protected: void __thiscall CSmsBaseWatcher::StartSocketWatchersL(void)
	?StoreMsgL@CBaseSmsActiveSocketWatcher@@QAEXPAVCSmsMessage@@@Z @ 31 NONAME ; public: void __thiscall CBaseSmsActiveSocketWatcher::StoreMsgL(class CSmsMessage *)
	?PreStoreActionL@CBaseSmsActiveSocketWatcher@@MAEXAAVCMsvSession@@AAVCSmsMessage@@@Z @ 32 NONAME ; void CBaseSmsActiveSocketWatcher::PreStoreActionL(class CMsvSession &, class CSmsMessage &)

